###################################################
### chunk number 1: Init
###################################################
options(width = 60)
library("tm")
data("crude")


###################################################
### chunk number 2: Ovid
###################################################
txt <- system.file("texts", "txt", package = "tm")
(ovid <- Corpus(DirSource(txt),
                readerControl = list(reader = readPlain,
                                     language = "la")))


###################################################
### chunk number 3: Mails
###################################################
newsgroup <- system.file("texts", "newsgroup", package = "tm")

Corpus(DirSource(newsgroup),
       readerControl = list(reader = readNewsgroup,
                            language = "en_US"))


###################################################
### chunk number 4: VectorSource
###################################################
docs <- c("This is a text.", "This another one.")
Corpus(VectorSource(docs))


###################################################
### chunk number 5: Reuters
###################################################
reut21578 <- system.file("texts", "reut21578", package = "tm")
reuters <- Corpus(DirSource(reut21578),
                  readerControl = list(reader = readReut21578XML))


###################################################
### chunk number 6:  eval=FALSE
###################################################
## lapply(ovid,
##        function(x) writeLines(x, paste(ID(x), ".txt", sep = "")))


###################################################
### chunk number 7: 
###################################################
inspect(ovid[1:2])


###################################################
### chunk number 8: 
###################################################
reuters <- tmMap(reuters, asPlain)


###################################################
### chunk number 9: 
###################################################
reuters <- tmMap(reuters, stripWhitespace)


###################################################
### chunk number 10: 
###################################################
reuters <- tmMap(reuters, tmTolower)


###################################################
### chunk number 11: 
###################################################
reuters <- tmMap(reuters, removeWords, stopwords("english"))


###################################################
### chunk number 12: 
###################################################
tmMap(reuters, stemDoc)


###################################################
### chunk number 13: 
###################################################
query <- "identifier == '10' &
  heading == 'COMPUTER TERMINAL SYSTEMS <CPML> COMPLETES SALE'"
tmFilter(reuters, query)


###################################################
### chunk number 14: 
###################################################
tmFilter(reuters, FUN = searchFullText,
         pattern = "partnership", doclevel = TRUE)


###################################################
### chunk number 15: DublinCore
###################################################
DublinCore(crude[[1]], "Creator") <- "Ano Nymous"
meta(crude[[1]])


###################################################
### chunk number 16: 
###################################################
meta(crude, tag = "test", type = "corpus") <- "test meta"
meta(crude, type = "corpus")
meta(crude, "foo") <- letters[1:20]
meta(crude)


###################################################
### chunk number 17: 
###################################################
reuters[[1]] %IN% reuters
crude[[1]] %IN% reuters


###################################################
### chunk number 18: 
###################################################
tdm <- TermDocMatrix(reuters)
Data(tdm)[1:5,150:155]


###################################################
### chunk number 19: 
###################################################
findFreqTerms(tdm, 5)


###################################################
### chunk number 20: 
###################################################
findAssocs(tdm, "crop", 0.97)[31:40]


###################################################
### chunk number 21: 
###################################################
removeSparseTerms(tdm, 0.4)


###################################################
### chunk number 22: 
###################################################
(d <- Dictionary(c("dlrs", "crude", "oil")))


###################################################
### chunk number 23: 
###################################################
tdmD <- TermDocMatrix(reuters, list(dictionary = d))
Data(tdmD)


